==> alfresco-data-model-23.7.0.9-sources.jar: org/alfresco/repo/search/impl/querymodel/Selector.java <==
/*
 * #%L
 * Alfresco Data model classes
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.search.impl.querymodel;

import org.alfresco.service.namespace.QName;

/**
 * @author andyh
 *
 */
public interface Selector extends Source
{
    /**
     * The qname of the type or aspect to select 
     * @return QName
     */
    public QName getType();
    
    /**
     * The alias or name for the selector
     * This must be unique across all selectors in the query
     * 
     * @return String
     */
    public String getAlias();
}

==> alfresco-data-model-25.2.3.1-sources.jar: org/alfresco/repo/search/impl/querymodel/Selector.java <==
/*
 * #%L
 * Alfresco Data model classes
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.search.impl.querymodel;

import org.alfresco.service.namespace.QName;

/**
 * @author andyh
 *
 */
public interface Selector extends Source
{
    /**
     * The qname of the type or aspect to select
     * 
     * @return QName
     */
    public QName getType();

    /**
     * The alias or name for the selector This must be unique across all selectors in the query
     * 
     * @return String
     */
    public String getAlias();
}
